/*

    ThermostatQA - test framework for Thermostat Monitoring Tool

    Copyright 2013 Red Hat, Inc.

This file is part of ThermostatQA

ThermostatQA is distributed under the GNU General Public License,
version 2 or any later version (with a special exception described
below, commonly known as the "Classpath Exception").

A copy of GNU General Public License (GPL) is included in this
distribution, in the file COPYING.

Linking ThermostatQA code with other modules is making a combined work
based on ThermostatQA.  Thus, the terms and conditions of the GPL
cover the whole combination.

As a special exception, the copyright holders of ThermostatQA give you
permission to link this code with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on ThermostatQA code.  If you modify ThermostatQA, you may
extend this exception to your version of the software, but you are
not obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.thermostat.qa.testsuites;



import org.thermostat.qa.annotations.TestType;
import org.thermostat.qa.annotations.TestTypes;
import org.thermostat.qa.framework.Assert;
import org.thermostat.qa.framework.ThermostatTest;
import org.thermostat.qa.reporter.FileUtils;



import java.io.IOException;
import java.util.List;


/**
 * Class CliClientSmokeTest
 * contains basic smoke tests for the thermostat shell client.  
 * Each of the tests starts storage, start the thermostat shell,
 * and check the output in the shell for specific commands issued.
 * Then the storage is stopped again.
 *
 */
@TestType(TestTypes.CLI_TEST)
public class CliClientSmokeTest extends ThermostatTest
{
    public static final String[] allscripts = new String[] {"exit_therm_shell.txt", "help_therm_shell.txt"};
    private String pathToOutputTexts;
    private String[] thermostatShellHelpMessage, thermostatShellExitMessage;

    @Override
    protected void tearDown()
    {
        // TODO Auto-generated method stub
        
    }

    @Override
    protected void setUp()
    {
        pathToOutputTexts = "outputtexts/"+this.configuration.getThermostatVersion()+"/";
        this.thermostatShellHelpMessage = FileUtils.getStringArrayFromOutputTextFile(this.pathToOutputTexts+"output_of_help_therm_shell.txt");
        this.thermostatShellExitMessage = FileUtils.getStringArrayFromOutputTextFile(this.pathToOutputTexts+"output_of_exit_therm_shell.txt");
    }
    
    /**
     * Method testCliClientStartOutput
     * starts storage, starts the thermostat shell and checks the output
     * of the shell.
     * 
     * This test uses the text file
     * <a href="scripts/exit_therm_shell.txt">exit_therm_shell.txt</a>.
     * 
     * @throws IOException
     */
    public void testCliClientStartOutput() throws IOException
    {
        startStorage();
        
        // run shell command exit
        List<String> output = runCommandsInThermostatShell("exit_therm_shell.txt");
        
        // test the output + some logging
        Assert.assertNotNull(output, "error getting standard output");
        for (String s : output)
        {
            logInfo("run", "Thermostat shell: " +  s);
        }
        
        Assert.assertTrue(output.size() >= this.thermostatShellExitMessage.length,
                        "too few lines in the thermostat shell output");
                
        compareListAndArrayOfStrings(output, this.thermostatShellExitMessage);
        
        stopStorage();
    }
    
    /**
     * Method testCliClientHelpOutput
     * starts storage, starts the thermostat shell, issues the command "help"
     * and checks the output of the shell.
     * 
     * This test uses the text file
     * <a href="scripts/help_therm_shell.txt">help_therm_shell.txt</a>.
     * 
     * @throws IOException
     */
    public void testCliClientHelpOutput() throws IOException
    {
        startStorage();
        
        // run shell command help
        List<String> output = runCommandsInThermostatShell("help_therm_shell.txt");
        
        // test the output + some logging
        Assert.assertNotNull(output, "error getting standard output");
        for (String s : output)
        {
            logInfo("run", "Thermostat shell: " +  s);
        }
        
        Assert.assertTrue(output.size() >= this.thermostatShellHelpMessage.length,
                        "too few lines in the thermostat shell output");
        
        compareListAndArrayOfStrings(output, this.thermostatShellHelpMessage);
        
        stopStorage();
    }
  
    public static void main(String[] args) {
        new CliClientSmokeTest().doTests(args);
    }
}
